This will be the specific thread for this issue, as a bug report (for the sake of finding it better) - scene has slower viewport performance with Corona 11 than Corona 10.
The root cause of this has been found. It is because of having a material previewed in the viewport, which has input in BaseColor slot involving MappingRandomizer. Can be texture specific too.
Removing MappingRandomizer from material tree (but keeping the rest) or disabling the material’s preview in viewport fixed the slow viewport.
Was this addressed in the recent hotfix? If not, are likely to get a second hotfix? I’d say a large portion of us are using mapping randomizer. Removing it just from the BaseColour isn’t really a valid option. I’d say that’s the most important map slot for it to be used in.
Will this be addressed in the next hotfix? We can’t disconnect the uvrandomizer map from basecolor. What’s the point of having a uvrandomizer if you can’t use it?
It is not suggested to remove MappingRandomizer from BaseColor slot of material or not have it at all - this was mentioned for identifying for anyone interested where the issue was.
The issue is when such material is previewed in the viewport - mapping randomizer is not going to be previewed in the viewport fully anyways (base texture with simple tiling is previewed), so just disabling the material preview will be enough.
By the way - this case was scene/material/object specific (not able to reproduce in a simple scene) and was exactly because of CoronaColorCorrect > CoronaMappingRandomizer > BaseColor slot (without any inputs, any of them) for a material, which is previewed in the viewport (probably for these specific objects too). A new material from scratch was creating like mentioned, and the viewport was slow.
But what is the strangest part - if the same material was applied to ALL of the objects in the scene, the viewport was fast, from 5 fps to 90fps…
Even if the original user submitted material was applied to all the objects in the scene, the viewport was fast… but not if applied to the original objects.
It was a very strange scene indeed.
just updated to corona 11 and worked on a scene previously made with corona 9.
finally found the elements. as soon as i turned the objects with the problematic material on the fps dropped to 0-3.
i do use randomizer regularly. in this case removing the randomizer didnt help. i also had to use the multimap too (which i always use for color variations).
please fix this. i will run into problems with most of the scenes now!
problem still exists for me although i removed randomizer.
seems to a problem with an arroway texture (they are large of course). i use arroway textures for wood a lot and never ran into any problem with previous corona version. i can send u scene if u like?
I just wanted to confirm that I tested my problematic scene with Corona 11 HF2 in both 3ds Max 2022 and 2024, and it seems that the problem is now resolved. The viewport behaves smoothly.
Thank you and the entire Corona Renderer team for listening and support.